Residual Disease Paper
========================================================
Comparing Ovary and Omentum Expression
-------------------------------------------------------

by Shelley Herbrich

*May 13, 2013*






## 1 Executive Summary

### 1.1 Introduction

In this report, we compare the PCR expression of our target genes between ovary and omental samples. 

We also compare FABP4 exression between ovary and omental samples from patients who had both available.

### 1.2 Data & Methods

In comparing PCR expression of our target genes between ovary and omental samples, we use PCR quantification summaries of samples run on the 17 plates containing tissue from both ovary and omentum. 

### 1.3 Results

We produce density plots of ADH1B and FABP4 expression by tissue. 

We see that for both genes, omental levels are markedly higher than ovary.

We produce a scatterplot of paired FABP4 values for 4 cases with data from both ovary and omentum available.

The measurement from omentum is higher than that from ovary in all 4 cases, with percent differences of 2%, 85%, 110% and 131%.

## 2 Loading PCR Data


```r
library(RColorBrewer)
```


```r
load(file.path("RDataObjects", "OMResults.RData"))
load(file.path("RDataObjects", "PCRResults.RData"))
```



```r
# match plates
plate <- unique(OMResults$Plate)
ovFABP4 <- PCRResults$FABP4[which(PCRResults$Plate %in% plate)]
ovADH1B <- PCRResults$ADH1B[which(PCRResults$Plate %in% plate)]
```


## 3 Analyses

### 3.1 Plotting Densities of ADH1B and FABP4 Expression


```r
# pdf(file='OVOMExpression.pdf',paper='USr')
plot(density(ovADH1B), col = "red", xlim = c(-30, -5), main = "ADH1B Expression")
lines(density(OMResults$ADH1B), col = "grey")
legend("topright", c("Ovary", "Omentum"), col = c("red", "grey"), lty = 1, bty = "n")
```

![plot of chunk plotDensities](figure/plotDensities1.png) 

```r

plot(density(ovFABP4), col = "red", xlim = c(-30, -5), main = "FABP4 Expression")
lines(density(OMResults$FABP4), col = "grey")
legend("topright", c("Ovary", "Omentum"), col = c("red", "grey"), lty = 1, bty = "n")
```

![plot of chunk plotDensities](figure/plotDensities2.png) 

```r
# dev.off()
```


### 3.2 Scatterplot of FABP4 and ADH1B from omentum versus primary

The following scatterplot shows FABP4 values in primary tumor and omentum for the 4 patients in the validation cohort who had both types of tumor tissue assayed.

Solid symbols show cases with RD. The dashed line indicates equality.


```r

pairsOV <- c("M20", "M59", "M65", "M34")
pairsOM <- c("OM1", "OM20", "OM40", "OM3")
sym <- c(16, 16, 1, 16)

ovPaired <- c()
omPaired <- c()

for (i in 1:4) {
    ovPaired <- c(ovPaired, PCRResults$FABP4[which(PCRResults$Sample.Name == 
        pairsOV[i])])
    omPaired <- c(omPaired, OMResults$FABP4[which(OMResults$Sample.Name == pairsOM[i])])
}

plot(ovPaired, omPaired, xlab = "FABP4 Expression from Primary Tumor", ylab = "FABP4 Expression from Omental Tumor", 
    xlim = c(-30, -10), ylim = c(-30, -10), pch = sym)

abline(0, 1, col = "red", lty = 2)
```

![plot of chunk plotOmentumPrimary](figure/plotOmentumPrimary.png) 

```r

ovPaired/omPaired
```

```
## [1] 1.850 1.021 2.104 2.314
```


## Appendix


```r
getwd()
```

```
## [1] "/Users/slt/SLT WORKSPACE/EXEMPT/OVARIAN/Ovarian residual disease study 2012/RD manuscript/Web page for paper/Webpage"
```



```r
sessionInfo()
```

```
## R version 3.0.2 (2013-09-25)
## Platform: x86_64-apple-darwin10.8.0 (64-bit)
## 
## locale:
## [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8
## 
## attached base packages:
## [1] stats     graphics  grDevices utils     datasets  methods   base     
## 
## other attached packages:
## [1] RColorBrewer_1.0-5 knitr_1.5         
## 
## loaded via a namespace (and not attached):
## [1] evaluate_0.5.1 formatR_0.10   stringr_0.6.2  tools_3.0.2
```

